package PGP5::Mail;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);

require Exporter;

@ISA = qw(Exporter);
@EXPORT_OK = qw(
	pgp5_mail
);
$VERSION = '0.01';

use Data::Dumper;
use Mail::Send;
use PGP5::Pipe;
use PGP5::Keyring;

##-------------------------------------------------------
sub text
{
    my($text, @dest)=@_;
    $text=~s/\r//g;
    $text=~s/\n/\r\n/g;
    return binary($text, @dest);
}

##-------------------------------------------------------
sub binary
{
    my($text, @dest)=@_;

    my($pgp, $keyring);
    $pgp=new PGP5::Pipe;
    die "Unable to create PGP5::Pipe\n" unless ref $pgp;
    $keyring=new PGP5::Keyring $pgp;
    die "Unable to create PGP5::Keyring\n" unless ref $keyring;

    my(@crypt, $err, @keys, $key);
    foreach my $dest (@dest)
    {
        $key=$keyring->Find(Desc=>$dest);
        unless($key)
        {
            push @crypt, "Unable to find PGP5 key for '$dest'";
        } else
        {
            push @keys, $key;
        }
    }

    unless(@keys)
    {
        die "No PGP5 keys found!\nLooking for :\n", join("\n", @dest), "\nIn ", Dumper $keyring;
    }

    my $crypt=$pgp->Encrypt(Text=>$text,
                            Armor=>1,
                            Key=>\@keys,
                            # Ascii=>1,
                           );
    if($crypt)
    {
         push @crypt, $crypt;
    } else
    {
         push @crypt, 'Error encrypting!';
    } 
    
    return join "\n", @crypt;
}

##-------------------------------------------------------
sub mail
{
    my($subject, $text, @dest)=@_;
    my $crypt;
    eval { $crypt=text($text, @dest);};

    my @errors;
    push @errors, $@ if $@;

    if($crypt)
    {
        foreach my $dest (@dest)
        {
            # print "HELLO\n";
            my $mail=new Mail::Send Subject=>$subject,
                                    To=>$dest;
            my $fh;
            eval {$fh=$mail->open('sendmail');};
            # print "HOW\n", Dumper $mail, $fh;
            
            unless($fh and ref $fh)
            {
                push @errors, "Unable to send to $dest\n";
                push @errors, $@ if $@;
            }
            $fh->print($crypt);
            $fh->close();
        }
        return 1 unless @errors;
    } 

    die @errors if @errors;
    return 0;
}

##-------------------------------------------------------
*pgp5_mail=\&mail;
*pgp5_text=\&text;


1;
__END__
# Below is the stub of documentation for your module. You better edit it!

=head1 NAME

PGP5::Mail - Perl extension for blah blah blah

=head1 SYNOPSIS

  use PGP5::Mail;
  blah blah blah

=head1 DESCRIPTION

Stub documentation for PGP5::Mail was created by h2xs. It looks like the
author of the extension was negligent enough to leave the stub
unedited.

Blah blah blah.

=head1 AUTHOR

A. U. Thor, a.u.thor@a.galaxy.far.far.away

=head1 SEE ALSO

perl(1).

=cut
